@@ -6,15 +6,20 @@ import os
 import sys
 import threading
 import time
-import traceback
 from loguru import logger
 
 #  时间输出格式为：2020-01-01 00:00:00
 logid = logger.add("run.log", 
            rotation="1 days",
            retention="7 days",
-           format="{time:YYYY-MM-DD HH:mm:ss} {level} {message}",
-           colorize=False,
+           format="{time:YYYY-MM-DD HH:mm:ss} | {level:<8} |{message}",
+           enqueue=True,
+           catch=True,
+           level="DEBUG")
+logger.remove(0)
+logger.add(sys.stdout, 
+           format="{time:YYYY-MM-DD HH:mm:ss} | <blue><bold>{level:<8}</bold></blue> | {message}",
+           colorize=True,
            enqueue=True,
            catch=True,
            level="DEBUG")
@@ -23,8 +28,7 @@ logid = logger.add("run.log",
 logger.add("error.log", 
         rotation="1 days",
         retention="7 days",
-        format="{time:YYYY-MM-DD HH:mm:ss} {level} {message}",
-        colorize=False,
+        format="{time:YYYY-MM-DD HH:mm:ss} | {level} | {message}",
         enqueue=True,
         catch=True,
         level="ERROR")
@@ -392,13 +396,13 @@ def monky_print(*args, **kwargs):
             isException = True
             break
     if isException:
-        logger.exception(f'{file_name}:{line} {thread_name} {thread_count} {args}')
+        logger.opt(colors=True).exception(f'<yellow>{file_name}:{line}</yellow>(<blue>{thread_name}:{thread_count}</blue>) {args}')
     else:
         # 将args转换为字符串
         args = [str(arg) for arg in args]
         # 将字符串拼接起来
         args = " ".join(args)
-        logger.info(f'thread_name:{thread_name} thread_count:{thread_count} {file_name}:{line} {args}')
+        logger.opt(colors=True).info(f'<yellow>{file_name}:{line}</yellow>(<blue>{thread_name}:{thread_count}</blue>) {args}')
     
         
 # print = monky_print
\ No newline at end of file
